@@ -81,18 +81,18 @@ class BivariateNSEmpirical(BaseCapacityModel):
         self,
         demand_data: np.ndarray,
         renewables_data: np.ndarray,
-        gen_distribution: Independent,
+        gen_distributions: t.List[acg_models.NonSequential],
         season_length: int = None,
     ):
         """
-
         Args:
-          demand_data (np.ndarray): Demand data matrix with two columns
-          gen_distribution (Independent): A bivariate distribution with independent components, where each component is a univar.Binned instance representing the distribution of available conventional generation for the corresponding area
-          renewables_data (np.ndarray): Renewable generation data matrix with two columns
-          season_length (int, optional): length of peak season. If None, it is set as the length of demand data
+            demand_data (np.ndarray): Demand data matrix with two columns
+            renewables_data (np.ndarray): Renewable generation data matrix with two columns
+            gen_distributions (t.List[acg_models.NonSequential]): List of non-sequential ACG objects
+            season_length (int, optional): length of peak season. If None, it is set as the length of demand data
 
         """
+        gen_distribution = Independent(x=gen_distributions[0], y=gen_distributions[1])
         warnings.warn("Coercing data to integer values.", stacklevel=2)
 
         self.demand_data = np.ascontiguousarray(demand_data, dtype=np.int32)
@@ -142,7 +142,7 @@ class BivariateNSEmpirical(BaseCapacityModel):
         )
 
     def cdf(self, x: np.ndarray, itc_cap: int = 1000, policy: str = "veto"):
-        """Evaluates the bivariate post-interconnection capacity surplus distribution's cumulative distribution function
+        """Evaluates the bivariate post-interconnection time-collapsed capacity surplus distribution's cumulative distribution function
 
         Args:
             x (np.ndarray): value at which to evaluate the cdf
@@ -323,14 +323,17 @@ class BivariateNSEmpirical(BaseCapacityModel):
 
     def get_pointwise_risk(
         self, x: np.ndarray, itc_cap: int = 1000, policy: str = "veto"
-    ):
-        """Calculates the post-interconnection shortfall probability for each one of the net demand observations
+    ) -> np.ndarray:
+        """Calculates the post-interconnection time-collapsed shortfall probability for each one of the net demand observations
 
         Args:
             x (np.ndarray): point to evaluate CDF at
             itc_cap (int, optional): interconnection capacity
-            policy (str): one of 'veto' or 'share'
+            policy (str, optional): one of 'veto' or 'share'
 
+
+        Returns:
+            np.ndarray: array with post-interconnection time-collapsed shortfall probabilities
         """
         pointwise_cdfs = np.empty((len(self.demand_data),))
         for k, (demand_row, renewables_row) in enumerate(
@@ -470,7 +473,7 @@ class BivariateNSEmpirical(BaseCapacityModel):
         itc_cap: int = 1000,
         policy: str = "veto",
     ):
-        """Simulate post-interconnection surplus distribution conditioned to a value in the other area's surplus
+        """Simulate post-interconnection capacity surplus distribution conditioned to a value in the other area's surplus
 
         Args:
             size (int): Sample size
@@ -592,9 +595,12 @@ class UnivariateSequential(BaseCapacityModel, BasePydanticModel):
         Args:
             args (t.Tuple[acg_models.Sequential, t.Dict, Path]): trace generation parameters
         """
-        gen, call_kwargs, filename = args
+        gen, call_kwargs, filename, compress_files = args
         traces = gen.simulate_seasons(**call_kwargs)
-        np.save(filename, traces)
+        if compress_files:
+            np.savez_compressed(filename, traces=traces)
+        else:
+            np.save(filename, traces)
 
     @classmethod
     def init(
@@ -609,7 +615,8 @@ class UnivariateSequential(BaseCapacityModel, BasePydanticModel):
         n_cores: int = 4,
         burn_in: int = 100,
         seed: int = None,
-    ) -> BaseCapacityModel:
+        compress_files: bool = False,
+    ) -> UnivariateSequential:
         """Generate and persists traces of conventional generation in files, and uses them to instantiate a surplus model. Returns a surplus model ready to perform computations with the generated files.
 
         Args:
@@ -623,8 +630,9 @@ class UnivariateSequential(BaseCapacityModel, BasePydanticModel):
             n_cores (int, optional): Number of cores to use.
             burn_in (int, optional): Parameter passed to acg_models.Sequential.simulate_seasons.
             seed (int, optional): Random seed passed to C backend. If not passed, output file paths are hashed to obtained it; this is because different seeds are needed for each file, otherwise traces are identical across files.
+            compress_files (bool, optional): Whether ACG trace files should be compressed
 
-        No Longer Returned:
+        Returns:
             UnivariateSequential: Sequential surplus model
 
         """
@@ -667,7 +675,7 @@ class UnivariateSequential(BaseCapacityModel, BasePydanticModel):
                 "burn_in": burn_in,
                 "seed": file_seed,
             }
-            arglist.append((gen, call_kwargs, output_path))
+            arglist.append((gen, call_kwargs, output_path, compress_files))
 
         # create files in parallel
         with Pool(n_cores) as executor:
@@ -900,7 +908,8 @@ class BivariateSequential(UnivariateSequential):
         season_length: int,
         n_cores: int = 4,
         burn_in: int = 100,
-    ) -> UnivariateSequential:
+        compress_files: bool = False,
+    ) -> BivariateSequential:
         """Generate and persists traces of conventional generation in files, and use them to instantiate a surplus model.
 
         Args:
@@ -913,6 +922,7 @@ class BivariateSequential(UnivariateSequential):
             season_length (int): Peak season length.
             n_cores (int, optional): Number of cores to use.
             burn_in (int, optional): Parameter passed to acg_models.Sequential.simulate_seasons.
+            compress_files (bool, optional): Whether ACG trace files should be compressed
 
         Returns:
             BivariateSequential: Sequential surplus model
@@ -934,6 +944,7 @@ class BivariateSequential(UnivariateSequential):
                 season_length=season_length,
                 n_cores=n_cores,
                 burn_in=burn_in,
+                compress_files=compress_files,
             )
 
         return cls(
@@ -1031,7 +1042,7 @@ class BivariateSequential(UnivariateSequential):
             return mapped
 
     def cdf(self, x: np.ndarray, itc_cap: float = 1000.0, policy="veto"):
-        """Evaluates the bivariate post-interconnection capacity surplus distribution's cumulative distribution function
+        """Evaluates the bivariate post-interconnection time-collapsed capacity surplus distribution's cumulative distribution function
 
         Args:
             x (np.ndarray): value at which to evaluate the cdf
