@@ -2,16 +2,18 @@
 #include <stdlib.h>
 #include <math.h>
 #include <limits.h>
+
 #include "mtwist-1.5/mtwist.h"
+
 #include "libbivarmargins.h"
 
 // documentation is in .h files 
 
-int imin(int a, int b){
+int int_min(int a, int b){
   return (a > b ) ? b : a;
 }
 
-int imax(int a, int b){
+int int_max(int a, int b){
   return (a > b ) ? a : b;
 }
 
@@ -105,7 +107,7 @@ double cond_eeu_share(BivariateDiscreteDistribution* F, ObservedData* obs, int c
 
     //EPU += -r*FX2.pdf(x2)*((x2-v1-v2)*(FX1.cdf(beta)-FX1.cdf(alpha-1)) + FX1.expectation(fro=alpha,to=beta ) )
     
-    beta = (int) min(beta0 + d1_div_d2*x2,v1+v2-x2);
+    beta = (int) double_min(beta0 + d1_div_d2*x2,v1+v2-x2);
     alpha = (int) ceil(alpha0 + d1_div_d2*x2);
     //gen2_pdf = (get_gen_array_val(x2,gen2_cdf_array,min_gen2,max_gen2) - get_gen_array_val(x2-1,gen2_cdf_array,min_gen2,max_gen2));
     gen2_pdf = gen_pdf(F->y,x2);
@@ -287,7 +289,7 @@ int axis2_polygon_upper_bound(Polygon* p, int x){
 
 int get_bounded_quantile(DiscreteDistribution* F, int upper_bound, double u){
   int lb = F->min, i=0;
-  int ub = (int) imin(upper_bound,F->max);
+  int ub = (int) int_min(upper_bound,F->max);
 
   double p_lb = gen_cdf(F,lb-1);
   double box_prob = gen_cdf(F,ub);
@@ -304,9 +306,9 @@ int veto_flow(int m1,int m2,int c){
 
   int res;
   if(m1 > 0 && m2 < 0){
-      res = -imin(c,imin(m1,-m2));
+      res = -int_min(c,int_min(m1,-m2));
   }else if(m1 < 0 && m2 > 0){
-      res = imin(c,imin(m2,-m1));
+      res = int_min(c,int_min(m2,-m1));
   }else{
       res = 0;
   }
@@ -317,7 +319,7 @@ double share_flow(int m1,int m2,int d1,int d2,int c){
 
   double flow;
   if(m1+m2 < 0 && m1 < c && m2 < c){
-    //res = min(c,max(-c,((float) d1)/(d1+d2)*m2 - ((float) d2)/(d1+d2)*m1));
+    //res = min(c,double_max(-c,((float) d1)/(d1+d2)*m2 - ((float) d2)/(d1+d2)*m1));
     flow = ((float) d1)/(d1+d2)*m2 - ((float) d2)/(d1+d2)*m1;
     flow = (flow >= c ? c : (flow <= -c ? -c: flow));
   }else{
@@ -397,24 +399,18 @@ double cond_bivariate_power_margin_cdf(BivariateDiscreteDistribution* F, Polygon
 }
 
 /*double bivariate_power_margin_cdf(BivariateDiscreteDistribution* F, IntMatrix* demand, IntMatrix* net_demand, SimulationParameters* pars){
-
   int i;
   double cdf_val = 0;
   ObservedData current_obs;
   Polygon plg1, plg2;
-
   for(i=0;i<demand->n_rows;++i){
-
     current_obs.net_demand1 = get_element(net_demand,i,0);
     current_obs.net_demand1 = get_element(net_demand,i,1);
     current_obs.demand1 = get_element(demand,i,0);
     current_obs.demand2 = get_element(demand,i,1);
-
     get_polygons(&plg1, &plg2, &current_obs, &pars);
-
     cdf_vals += cond_bivariate_power_margin_cdf(F, &plg1, &plg2);
   }
-
   return cdf_vals/demand->n_rows;
 }*/
 
@@ -445,8 +441,8 @@ int get_joint_polygon_x_bound(
     p1_crossing = plg1->p2->x + plg1->p2->y;
   }
 
-  compared = intersection > 0 ? imin(p1_crossing,p2_crossing) : imax(p1_crossing,p2_crossing);
-  return(imin(F->x->max,compared));
+  compared = intersection > 0 ? int_min(p1_crossing,p2_crossing) : int_max(p1_crossing,p2_crossing);
+  return(int_min(F->x->max,compared));
 
 }
 
@@ -462,9 +458,9 @@ int get_joint_polygon_y_bound_given_x(
   p1_y_bound = axis1_polygon_upper_bound(plg1,x);
   p2_y_bound = axis2_polygon_upper_bound(plg2,x);
 
-  compared = intersection > 0 ? imin(p1_y_bound,p2_y_bound) : imax(p1_y_bound,p2_y_bound);
+  compared = intersection > 0 ? int_min(p1_y_bound,p2_y_bound) : int_max(p1_y_bound,p2_y_bound);
   
-  return(imin(F->y->max,compared));
+  return(int_min(F->y->max,compared));
 
 }
 
@@ -484,7 +480,9 @@ void region_simulation(
   Polygon plg1 = {&p11,&p12}, plg2 = {&p21,&p22};
   ObservedData current_obs;
 
-  double x1_cond_cdf_array[F->x->max+1]; //not all entries will be filled, but it works
+  //double x1_cond_cdf_array[F->x->max+1]; //not all entries will be filled, but it works
+  double *x1_cond_cdf_array = (double *)malloc(F->x->max+1 * sizeof(double));
+
   DiscreteDistribution F_cond = {F->x->min, F->x->max, &x1_cond_cdf_array[0], F->x->expectation};
 
   int n_sim = 0, i, j;
@@ -553,6 +551,7 @@ void region_simulation(
       }
     }
   }
+  free(x1_cond_cdf_array);
 }
 
 void conditioned_simulation(
@@ -569,7 +568,9 @@ void conditioned_simulation(
 
   Coord p11 = {0,0}, p12 = {0,0}, p21 = {0,0}, p22 = {0,0};
   Polygon plg1 = {&p11,&p12};//, plg2 = {&p21,&p22};
-  double cond_x2_cdf[F->y->max+1]; //not all entries will be filled, but it works
+  
+  //double cond_x2_cdf[F->y->max+1]; //not all entries will be filled, but it works
+  double *cond_x2_cdf = (double *)malloc(F->y->max+1 * sizeof(double));
 
   DiscreteDistribution F_cond = {F->y->min, F->y->max, &cond_x2_cdf[0], F->y->expectation};
 /*  F_cond->min = F->y->min;
@@ -641,6 +642,7 @@ void conditioned_simulation(
 
     }
   }
+  free(cond_x2_cdf);
 }
 
 void bivariate_empirical_cdf(
@@ -915,13 +917,10 @@ void conditioned_simulation_py_interface(
   double* ecdf,
   double* X,
   int n){
-
   DoubleVector ecdf_vector;
   DoubleMatrix X_matrix; 
-
   get_int_matrix_from_py_objs(&X_matrix, X, n, 2);
   get_double_vector_from_py_objs(&ecdf_vector,ecdf,n);
-
   bivariate_empirical_cdf(&ecdf_vector,&X_matrix);
 }*/
 
@@ -939,31 +938,22 @@ void conditioned_simulation_py_interface(
   int m2,
   int c,
   int share_policy){
-
   int i;
-
   DiscreteDistribution X;
   DiscreteDistribution Y;
   BivariateDiscreteDistribution F;
-
   get_discrete_dist_from_py_objs(&X, gen1_cdf_array, gen1_cdf_array, min_gen1, max_gen1);
   get_discrete_dist_from_py_objs(&Y, gen2_cdf_array, gen2_cdf_array, min_gen2, max_gen2);
   F.x = &X;
   F.y = &Y;
-
   IntMatrix net_demand_matrix;
   IntMatrix demand_matrix;
-
   get_int_matrix_from_py_objs(&net_demand_matrix, net_demand, n_rows, 2);
   get_int_matrix_from_py_objs(&demand_matrix, demand, n_rows, 2);
-
   SimulationParameters pars;
-
   // valid parameters: x_bound, y_bound, share_policy and c. All other are placeholders
   get_sim_pars_from_py_objs(&pars,m1,m2,gen1_cdf_array,1,1,share_policy,c,m1);
-
   return bivariate_power_margin_cdf(&F, &demand, &net_demand, &pars);
-
 }*/
 
 
@@ -1009,6 +999,4 @@ double cond_bivariate_power_margin_cdf_py_interface(
 
   return cond_bivariate_power_margin_cdf(&F, &plg1, &plg2);
 
-}
-
-
+}
\ No newline at end of file
